@@ -12,7 +12,7 @@ from packaging import version
 from .utils.file_utils import get_tf_version, pytorch_available, tf_available
 from .utils.logger import logger
 
-__version__ = 0.14
+__version__ = 0.16
 
 if not tf_available() and not pytorch_available():
     logger.info(
@@ -43,7 +43,7 @@ from .datapoint import *
 from .datasets import *
 from .eval import *
 from .extern import *
-from .mapper import *  # pylint: disable = W0622
+from .mapper import *
 from .pipe import *
 from .train import *
 from .utils import *
