@@ -36,7 +36,7 @@ from ..pipe.text import TextExtractionService, TextOrderService
 from ..utils.file_utils import pytorch_available, tensorpack_available, tf_available
 from ..utils.fs import mkdir_p
 from ..utils.logger import logger
-from ..utils.metacfg import set_config_by_yaml
+from ..utils.metacfg import AttrDict, set_config_by_yaml
 from ..utils.settings import names
 from ..utils.systools import get_configs_dir_path, get_package_path
 
@@ -67,14 +67,14 @@ def _auto_select_lib_and_device() -> Tuple[str, str]:
     """
     if tf_available():
         if get_num_gpu() >= 1:
-            return "TF", "cuda"
+            return "tf", "cuda"
         if pytorch_available():
-            return "PT", "cpu"
+            return "pt", "cpu"
         raise ImportError("No GPU is available. You must install Pytorch in order to run on a CPU")
     if pytorch_available():
         if cuda.is_available():
-            return "PT", "gpu"
-        return "PT", "cpu"
+            return "pt", "gpu"
+        return "pt", "cpu"
     raise ImportError(
         "Neither Pytorch nor Tensorflow are installed. You must install at least one of them before "
         "running the analyzer. Note, that if no GPU is available you can only use Detectron2 along "
@@ -97,6 +97,120 @@ def _maybe_copy_config_to_cache(file_name: str) -> str:
     return absolute_path
 
 
+def build_analyzer(cfg: AttrDict) -> DoctectionPipe:
+    """
+    Builds the analyzer with a given config
+
+    :param cfg: A configuration
+    :return: Analyzer pipeline
+    """
+    pipe_component_list: List[PipelineComponent] = []
+
+    d_layout: Union[D2FrcnnDetector, TPFrcnnDetector]
+    if cfg.LIB == "tf":
+        layout_config_path = ModelCatalog.get_full_path_configs(cfg.CONFIG.TPLAYOUT)
+        layout_weights_path = ModelDownloadManager.maybe_download_weights_and_configs(cfg.WEIGHTS.TPLAYOUT)
+        categories_layout = ModelCatalog.get_profile(cfg.WEIGHTS.TPLAYOUT).categories
+        assert categories_layout is not None
+        assert layout_weights_path is not None
+        d_layout = TPFrcnnDetector(layout_config_path, layout_weights_path, categories_layout)
+    else:
+        layout_config_path = ModelCatalog.get_full_path_configs(cfg.CONFIG.D2LAYOUT)
+        layout_weights_path = ModelDownloadManager.maybe_download_weights_and_configs(cfg.WEIGHTS.D2LAYOUT)
+        categories_layout = ModelCatalog.get_profile(cfg.WEIGHTS.D2LAYOUT).categories
+        assert categories_layout is not None
+        assert layout_weights_path is not None
+        d_layout = D2FrcnnDetector(layout_config_path, layout_weights_path, categories_layout, device=cfg.DEVICE)
+    layout = ImageLayoutService(d_layout, to_image=True, crop_image=True)
+    pipe_component_list.append(layout)
+
+    # setup tables service
+    if cfg.TAB:
+        d_cell: Optional[Union[D2FrcnnDetector, TPFrcnnDetector]]
+        d_item: Union[D2FrcnnDetector, TPFrcnnDetector]
+        if cfg.LIB == "tf":
+            cell_config_path = ModelCatalog.get_full_path_configs(cfg.CONFIG.TPCELL)
+            cell_weights_path = ModelDownloadManager.maybe_download_weights_and_configs(cfg.WEIGHTS.TPCELL)
+            categories_cell = ModelCatalog.get_profile(cfg.WEIGHTS.TPCELL).categories
+            assert categories_cell is not None
+            d_cell = TPFrcnnDetector(
+                cell_config_path,
+                cell_weights_path,
+                categories_cell,
+            )
+            item_config_path = ModelCatalog.get_full_path_configs(cfg.CONFIG.TPITEM)
+            item_weights_path = ModelDownloadManager.maybe_download_weights_and_configs(cfg.WEIGHTS.TPITEM)
+            categories_item = ModelCatalog.get_profile(cfg.WEIGHTS.TPITEM).categories
+            assert categories_item is not None
+            d_item = TPFrcnnDetector(item_config_path, item_weights_path, categories_item)
+        else:
+            cell_config_path = ModelCatalog.get_full_path_configs(cfg.CONFIG.D2CELL)
+            cell_weights_path = ModelDownloadManager.maybe_download_weights_and_configs(cfg.WEIGHTS.D2CELL)
+            categories_cell = ModelCatalog.get_profile(cfg.WEIGHTS.D2CELL).categories
+            assert categories_cell is not None
+            d_cell = D2FrcnnDetector(cell_config_path, cell_weights_path, categories_cell, device=cfg.DEVICE)
+            item_config_path = ModelCatalog.get_full_path_configs(cfg.CONFIG.D2ITEM)
+            item_weights_path = ModelDownloadManager.maybe_download_weights_and_configs(cfg.WEIGHTS.D2ITEM)
+            categories_item = ModelCatalog.get_profile(cfg.WEIGHTS.D2ITEM).categories
+            assert categories_item is not None
+            d_item = D2FrcnnDetector(item_config_path, item_weights_path, categories_item, device=cfg.DEVICE)
+
+        cell = SubImageLayoutService(d_cell, names.C.TAB, {1: 6}, True)
+        pipe_component_list.append(cell)
+
+        item = SubImageLayoutService(d_item, names.C.TAB, {1: 7, 2: 8}, True)
+        pipe_component_list.append(item)
+
+        table_segmentation = TableSegmentationService(
+            cfg.SEGMENTATION.ASSIGNMENT_RULE,
+            cfg.SEGMENTATION.IOU_THRESHOLD_ROWS
+            if cfg.SEGMENTATION.ASSIGNMENT_RULE in ["iou"]
+            else cfg.SEGMENTATION.IOA_THRESHOLD_ROWS,
+            cfg.SEGMENTATION.IOU_THRESHOLD_COLS
+            if cfg.SEGMENTATION.ASSIGNMENT_RULE in ["iou"]
+            else cfg.SEGMENTATION.IOA_THRESHOLD_COLS,
+            cfg.SEGMENTATION.FULL_TABLE_TILING,
+            cfg.SEGMENTATION.REMOVE_IOU_THRESHOLD_ROWS,
+            cfg.SEGMENTATION.REMOVE_IOU_THRESHOLD_COLS,
+        )
+        pipe_component_list.append(table_segmentation)
+
+        if cfg.TAB_REF:
+            table_segmentation_refinement = TableSegmentationRefinementService()
+            pipe_component_list.append(table_segmentation_refinement)
+
+    # setup ocr
+    if cfg.OCR:
+
+        tess_ocr_config_path = get_configs_dir_path() / cfg.CONFIG.TESS_OCR
+        d_tess_ocr = TesseractOcrDetector(
+            tess_ocr_config_path, config_overwrite=[f"LANGUAGES={cfg.LANG}"] if cfg.LANG is not None else None
+        )
+        text = TextExtractionService(d_tess_ocr, None, {1: 9})
+        pipe_component_list.append(text)
+
+        match = MatchingService(
+            parent_categories=cfg.WORD_MATCHING.PARENTAL_CATEGORIES,
+            child_categories=names.C.WORD,
+            matching_rule=cfg.WORD_MATCHING.RULE,
+            threshold=cfg.WORD_MATCHING.IOU_THRESHOLD
+            if cfg.WORD_MATCHING.RULE in ["iou"]
+            else cfg.WORD_MATCHING.IOA_THRESHOLD,
+        )
+        pipe_component_list.append(match)
+
+        order = TextOrderService(
+            text_container=names.C.WORD,
+            floating_text_block_names=[names.C.TITLE, names.C.TEXT, names.C.LIST],
+            text_block_names=[names.C.TITLE, names.C.TEXT, names.C.LIST, names.C.CELL, names.C.HEAD, names.C.BODY],
+        )
+        pipe_component_list.append(order)
+
+    pipe = DoctectionPipe(pipeline_component_list=pipe_component_list)
+
+    return pipe
+
+
 def get_dd_analyzer(
     tables: bool = True, ocr: bool = True, table_refinement: bool = True, language: Optional[str] = None
 ) -> DoctectionPipe:
@@ -132,9 +246,20 @@ def get_dd_analyzer(
 
     lib, device = _auto_select_lib_and_device()
     dd_one_config_path = _maybe_copy_config_to_cache(_DD_ONE)
-    # Set up of the configuration and logging
+    _maybe_copy_config_to_cache(_TESSERACT)
 
+    # Set up of the configuration and logging
     cfg = set_config_by_yaml(dd_one_config_path)
+
+    cfg.freeze(freezed=False)
+    cfg.LIB = lib
+    cfg.DEVICE = device
+    cfg.TAB = tables
+    cfg.TAB_REF = table_refinement
+    cfg.OCR = ocr
+    cfg.LANG = language
+    cfg.freeze()
+
     logger.info("Deep Doctection Analyzer Config: ------------------------------------------\n %s", str(cfg))
 
     logger.info(
@@ -142,126 +267,22 @@ def get_dd_analyzer(
         "tables and figures."
     )
 
-    if tables:
+    if cfg.TAB:
         logger.info(
             "As tables have been chosen, a table recognition system will be invoked. This means, "
             "that the interior of each detected table will be segmented into cells, rows and column and every "
             "cell will be labeled with its row and column position as well as its spans."
         )
 
-    if ocr:
+    if cfg.OCR:
         logger.info(
             " OCR will be performed and each words will be assigned to the detected layout "
             "compartment, if possible. Finally, words will be stringed together according to its"
             " reading order."
         )
 
-    pipe_component_list: List[PipelineComponent] = []
-
     # will silent all TP loggings while building the tower
     if tensorpack_available():
         disable_tp_layer_logging()
 
-    d_layout: Union[D2FrcnnDetector, TPFrcnnDetector]
-    if lib == "TF":
-        layout_config_path = ModelCatalog.get_full_path_configs(cfg.CONFIG.TPLAYOUT)
-        layout_weights_path = ModelDownloadManager.maybe_download_weights_and_configs(cfg.WEIGHTS.TPLAYOUT)
-        categories_layout = ModelCatalog.get_profile(cfg.WEIGHTS.TPLAYOUT).categories
-        assert categories_layout is not None
-        assert layout_weights_path is not None
-        d_layout = TPFrcnnDetector(layout_config_path, layout_weights_path, categories_layout)
-    else:
-        layout_config_path = ModelCatalog.get_full_path_configs(cfg.CONFIG.D2LAYOUT)
-        layout_weights_path = ModelDownloadManager.maybe_download_weights_and_configs(cfg.WEIGHTS.D2LAYOUT)
-        categories_layout = ModelCatalog.get_profile(cfg.WEIGHTS.D2LAYOUT).categories
-        assert categories_layout is not None
-        assert layout_weights_path is not None
-        d_layout = D2FrcnnDetector(layout_config_path, layout_weights_path, categories_layout, device=device)
-    layout = ImageLayoutService(d_layout, to_image=True, crop_image=True)
-    pipe_component_list.append(layout)
-
-    # setup tables service
-    if tables:
-        d_cell: Optional[Union[D2FrcnnDetector, TPFrcnnDetector]]
-        d_item: Union[D2FrcnnDetector, TPFrcnnDetector]
-        if lib == "TF":
-            cell_config_path = ModelCatalog.get_full_path_configs(cfg.CONFIG.TPCELL)
-            cell_weights_path = ModelDownloadManager.maybe_download_weights_and_configs(cfg.WEIGHTS.TPCELL)
-            categories_cell = ModelCatalog.get_profile(cfg.WEIGHTS.TPCELL).categories
-            assert categories_cell is not None
-            d_cell = TPFrcnnDetector(
-                cell_config_path,
-                cell_weights_path,
-                categories_cell,
-            )
-            item_config_path = ModelCatalog.get_full_path_configs(cfg.CONFIG.TPITEM)
-            item_weights_path = ModelDownloadManager.maybe_download_weights_and_configs(cfg.WEIGHTS.TPITEM)
-            categories_item = ModelCatalog.get_profile(cfg.WEIGHTS.TPITEM).categories
-            assert categories_item is not None
-            d_item = TPFrcnnDetector(item_config_path, item_weights_path, categories_item)
-        else:
-            cell_config_path = ModelCatalog.get_full_path_configs(cfg.CONFIG.D2CELL)
-            cell_weights_path = ModelDownloadManager.maybe_download_weights_and_configs(cfg.WEIGHTS.D2CELL)
-            categories_cell = ModelCatalog.get_profile(cfg.WEIGHTS.D2CELL).categories
-            assert categories_cell is not None
-            d_cell = D2FrcnnDetector(cell_config_path, cell_weights_path, categories_cell, device=device)
-            item_config_path = ModelCatalog.get_full_path_configs(cfg.CONFIG.D2ITEM)
-            item_weights_path = ModelDownloadManager.maybe_download_weights_and_configs(cfg.WEIGHTS.D2ITEM)
-            categories_item = ModelCatalog.get_profile(cfg.WEIGHTS.D2ITEM).categories
-            assert categories_item is not None
-            d_item = D2FrcnnDetector(item_config_path, item_weights_path, categories_item, device=device)
-
-        cell = SubImageLayoutService(d_cell, names.C.TAB, {1: 6}, True)
-        pipe_component_list.append(cell)
-
-        item = SubImageLayoutService(d_item, names.C.TAB, {1: 7, 2: 8}, True)
-        pipe_component_list.append(item)
-
-        table_segmentation = TableSegmentationService(
-            cfg.SEGMENTATION.ASSIGNMENT_RULE,
-            cfg.SEGMENTATION.IOU_THRESHOLD_ROWS
-            if cfg.SEGMENTATION.ASSIGNMENT_RULE in ["iou"]
-            else cfg.SEGMENTATION.IOA_THRESHOLD_ROWS,
-            cfg.SEGMENTATION.IOU_THRESHOLD_COLS
-            if cfg.SEGMENTATION.ASSIGNMENT_RULE in ["iou"]
-            else cfg.SEGMENTATION.IOA_THRESHOLD_COLS,
-            cfg.SEGMENTATION.FULL_TABLE_TILING,
-            cfg.SEGMENTATION.REMOVE_IOU_THRESHOLD_ROWS,
-            cfg.SEGMENTATION.REMOVE_IOU_THRESHOLD_COLS,
-        )
-        pipe_component_list.append(table_segmentation)
-
-        if table_refinement:
-            table_segmentation_refinement = TableSegmentationRefinementService()
-            pipe_component_list.append(table_segmentation_refinement)
-
-    # setup ocr
-    if ocr:
-        _maybe_copy_config_to_cache(_TESSERACT)
-        tess_ocr_config_path = os.path.join(get_configs_dir_path(), cfg.CONFIG.TESS_OCR)
-        d_tess_ocr = TesseractOcrDetector(
-            tess_ocr_config_path, config_overwrite=[f"LANGUAGES={language}"] if language is not None else None
-        )
-        text = TextExtractionService(d_tess_ocr, None, {1: 9})
-        pipe_component_list.append(text)
-
-        match = MatchingService(
-            parent_categories=cfg.WORD_MATCHING.PARENTAL_CATEGORIES,
-            child_categories=names.C.WORD,
-            matching_rule=cfg.WORD_MATCHING.RULE,
-            threshold=cfg.WORD_MATCHING.IOU_THRESHOLD
-            if cfg.WORD_MATCHING.RULE in ["iou"]
-            else cfg.WORD_MATCHING.IOA_THRESHOLD,
-        )
-        pipe_component_list.append(match)
-
-        order = TextOrderService(
-            text_container=names.C.WORD,
-            floating_text_block_names=[names.C.TITLE, names.C.TEXT, names.C.LIST],
-            text_block_names=[names.C.TITLE, names.C.TEXT, names.C.LIST, names.C.CELL, names.C.HEAD, names.C.BODY],
-        )
-        pipe_component_list.append(order)
-
-    pipe = DoctectionPipe(pipeline_component_list=pipe_component_list)
-
-    return pipe
+    return build_analyzer(cfg)
