@@ -20,20 +20,25 @@ Some additional DataFlow classes for transforming and processing datapoints
 """
 from typing import Any
 
-from dataflow.dataflow import ProxyDataFlow  # type: ignore
+from dataflow.dataflow import ProxyDataFlow
 
 
-class FlattenData(ProxyDataFlow):  # type: ignore
+class FlattenData(ProxyDataFlow):
     """
     Flatten an iterator within a datapoint. Will flatten the datapoint if it is a list or a tuple.
 
     **Example:**
 
-       dp_1 = ['a','b']
+        .. code-block:: python
 
-       dp_2 = ['c','d']
+            dp_1 = ['a','b']
+            dp_2 = ['c','d']
 
-       will stream 'a', 'b', 'c', 'd'.
+        will yield
+
+        .. code-block:: python
+
+            ['a'], ['b'], ['c'], ['d'].
     """
 
     def __iter__(self) -> Any:
