@@ -24,6 +24,7 @@ import numpy as np
 from dataflow import CacheData, DataFromIterable, DataFromList  # type: ignore
 
 from ..utils.logger import logger
+from ..utils.tqdm import get_tqdm
 
 __all__ = ["CacheData", "CustomDataFromList", "CustomDataFromIterable"]
 
@@ -35,25 +36,43 @@ def _get_cache(self: CacheData) -> List[Any]:
     :return: list of datapoints
     """
     self.reset_state()
-    for _ in self:
-        pass
-    return self.buffer
+    with get_tqdm() as status_bar:
+        for _ in self:
+            status_bar.update()
+        return self.buffer
 
 
 CacheData.get_cache = _get_cache
 
 
-class CustomDataFromList(DataFromList):  # type: ignore
+class CustomDataFromList(DataFromList):
     """
     Wraps a list of datapoints to a dataflow. Compared to :class:`Tensorpack.DataFlow.DataFromList` implementation you
     can specify a number of datapoints after that the iteration stops. You can also pass a rebalance function that
     filters on that list.
+
+    **Example:**
+
+        .. code-block:: python
+
+                def filter_first(lst):
+                    return lst.pop(0)
+
+                df = CustomDataFromList(lst=[["a","b"],["c","d"]],rebalance_func=filter_first)
+                df.reset_state()
+
+        will yield:
+
+        .. code-block:: python
+
+            ["c","d"]
+
     """
 
     def __init__(
         self,
         lst: List[Any],
-        shuffle: Optional[bool] = False,
+        shuffle: bool = False,
         max_datapoints: Optional[int] = None,
         rebalance_func: Optional[Callable[[List[Any]], List[Any]]] = None,
     ):
@@ -106,7 +125,7 @@ class CustomDataFromList(DataFromList):  # type: ignore
                 yield from lst_tmp
 
 
-class CustomDataFromIterable(DataFromIterable):  # type: ignore
+class CustomDataFromIterable(DataFromIterable):
     """
     Wrap an iterable of datapoints to a dataflow. Can stop iteration after max_datapoints.
     """
