@@ -25,17 +25,19 @@ evaluating the text extractions.
 import json
 import os
 from dataclasses import asdict, dataclass, field
-from typing import List, Optional
+from typing import List, Optional, Union
 
 import cv2
 import numpy as np
 
 from ..utils.detection_types import ImageType, JsonDict
+from ..utils.develop import deprecated
 from ..utils.settings import names
 from ..utils.viz import draw_boxes, interactive_imshow
 from .convert import convert_b64_to_np_array
 
 
+@deprecated("Use .page.Layout class instead", "2022-08-16")
 @dataclass
 class LayoutSegment:
     """
@@ -62,6 +64,7 @@ class LayoutSegment:
     score: Optional[float] = field(default_factory=float)
 
 
+@deprecated("Use .page.Cell class instead", "2022-08-16")
 @dataclass
 class Cell:
     """
@@ -106,6 +109,7 @@ class Cell:
         )
 
 
+@deprecated("Use .page.Layout class instead", "2022-08-16")
 @dataclass
 class TableSegment:
     """
@@ -144,6 +148,7 @@ def _get_table_str(cells: List[Cell], number_rows: int, plain: bool = False) ->
     return output
 
 
+@deprecated("Use .page.Table class instead", "2022-08-16")
 @dataclass
 class Table:
     """
@@ -188,6 +193,7 @@ class Table:
         return _get_table_str(self.cells, self.number_rows, True)
 
 
+@deprecated("Use .page.Page class instead", "2022-08-16")
 @dataclass
 class Page:
     """
@@ -226,7 +232,14 @@ class Page:
 
         return text
 
-    def viz(self, show_tables: bool = True, show_items: bool = True, interactive: bool = False) -> Optional[ImageType]:
+    def viz(
+        self,
+        show_tables: bool = True,
+        show_items: bool = True,
+        show_cells: bool = True,
+        show_table_structure: bool = True,
+        interactive: bool = False,
+    ) -> Optional[ImageType]:
         """
         Display a page detected bounding boxes. One can select bounding boxes of tables or other layout components.
 
@@ -241,11 +254,13 @@ class Page:
 
         :param show_tables: Will display all tables boxes as well as cells, rows and columns
         :param show_items: Will display all other layout components.
+        :param show_cells: Will display cells within tables. (Only available if `show_tables=True`)
+        :param show_table_structure: Will display rows and columns
         :param interactive: If set to True will open an interactive image, otherwise it will return a numpy array that
                             can be displayed differently.
         :return: If interactive will return nothing else a numpy array.
         """
-        category_names_list = []
+        category_names_list: List[Union[str, None]] = []
         box_stack = []
 
         if show_items:
@@ -257,12 +272,14 @@ class Page:
             for table in self.tables:
                 box_stack.append(table.bounding_box)
                 category_names_list.append(names.C.TAB)
-                for cell in table.cells:
-                    box_stack.append(cell.bounding_box)
-                    category_names_list.append(f"({cell.row_number},{cell.col_number})")
-                for segment_item in table.items:
-                    box_stack.append(segment_item.bounding_box)
-                    category_names_list.append(segment_item.category)
+                if show_cells:
+                    for cell in table.cells:
+                        box_stack.append(cell.bounding_box)
+                        category_names_list.append(None)
+                if show_table_structure:
+                    for segment_item in table.items:
+                        box_stack.append(segment_item.bounding_box)
+                        category_names_list.append(None)
 
         if self.image is not None:
             img = convert_b64_to_np_array(self.image)
@@ -296,7 +313,7 @@ class Page:
         """
 
         page_dict = self.as_dict()
-        with open(  # pylint: disable=W1514
-            os.path.join(path, os.path.splitext(page_dict["file_name"])[0] + ".json"), "w"
+        with open(
+            os.path.join(path, os.path.splitext(page_dict["file_name"])[0] + ".json"), "w", encoding="UTF-8"
         ) as file:
             json.dump(page_dict, file)
