@@ -18,9 +18,9 @@
 """
 Dataclass Image
 """
-from copy import deepcopy
+
 from dataclasses import dataclass, field
-from typing import Any, Dict, Iterable, List, Optional, Sequence, Union
+from typing import Any, Dict, Iterable, List, Optional, Sequence, Union, no_type_check
 
 import numpy as np
 from numpy import uint8
@@ -93,7 +93,7 @@ class Image:
             else:
                 self.image_id = get_uuid(external_id)
         else:
-            self.image_id = get_uuid(self.location, self.file_name)
+            self.image_id = get_uuid(str(self.location), self.file_name)
 
     @property
     def image_id(self) -> str:
@@ -368,7 +368,7 @@ class Image:
         A list of attributes to suspend from as_dict creation.
         """
 
-        return ["external_id", "_image", "_bbox", "_embeddings", "_annotations"]
+        return ["_image"]
 
     def define_annotation_id(self, annotation: Annotation) -> str:
         """
@@ -468,21 +468,53 @@ class Image:
             )
             ann.image.dump(sub_image)
 
-    def get_export(self) -> Dict[str, Any]:
+    def get_export(self, save_image: bool = False, highest_hierarchy_only: bool = False) -> Dict[str, Any]:
         """
         Exporting image as dictionary. As numpy array cannot be serialized :attr:`image` values will be converted into
         base64 encodings.
-
+        :param save_image: If True will save the image as b64 encoded string in output
+        :param highest_hierarchy_only: If True it will remove all image attributes of ImageAnnotations
         :return: Dict that e.g. can be saved to a file.
         """
-
-        image_copy = deepcopy(self)
-        image_copy.annotations = []
-        image_copy.image = np.ones((1, 1, 3), dtype=np.float32)
-        export_dict = image_copy.as_dict()
-        export_dict["annotations"] = []
-        export_dict["image"] = self.get_image().to_b64()
-        for ann in self.annotations:
-            export_dict["annotations"].append(ann.get_export())
-
+        if highest_hierarchy_only:
+            self.remove_image_from_lower_hierachy()
+        export_dict = self.as_dict()
+        if save_image and self.image is not None:
+            export_dict["_image"] = convert_np_array_to_b64(self.image)
         return export_dict
+
+    def remove_image_from_lower_hierachy(self) -> None:
+        """Will remove all images from image annotations."""
+        for ann in self.annotations:
+            if ann.image is not None:
+                absolute_bounding_box = ann.image.get_embedding(self.image_id)
+                ann.bounding_box = absolute_bounding_box
+                ann.image = None
+
+    @classmethod
+    @no_type_check
+    def from_dict(cls, **kwargs) -> "Image":
+        """
+        Create :class:`Image` instance from dict.
+
+        :param kwargs: dict with  :class:`Image` attributes and nested dicts for initializing annotations,
+        :return: Initialized image
+        """
+        image = cls(kwargs.get("file_name"), kwargs.get("location"), kwargs.get("external_id"))
+        image._image_id = kwargs.get("_image_id")
+        if b64_image := kwargs.get("_image"):
+            image.image = b64_image
+        if box_kwargs := kwargs.get("_bbox"):
+            image._bbox = BoundingBox.from_dict(**box_kwargs)
+        for image_id, box_dict in kwargs.get("embeddings").items():
+            image.set_embedding(image_id, BoundingBox.from_dict(**box_dict))
+        for ann_dict in kwargs.get("annotations"):
+            image_ann = ImageAnnotation.from_dict(**ann_dict)
+            if "image" in ann_dict:
+                image_dict = ann_dict["image"]
+                if image_dict:
+                    image_ann.image = cls.from_dict(**image_dict)
+            image.dump(image_ann)
+        if summary_dict := kwargs.get("summary"):
+            image.summary = SummaryAnnotation.from_dict(**summary_dict)
+        return image
