@@ -33,7 +33,6 @@ Module for Funsd dataset.  Install the dataset following the folder structure
 |    │ │ ├── ...
 """
 
-import json
 import os
 from typing import Dict, List, Mapping, Union
 
@@ -42,6 +41,7 @@ from ...datasets.info import DatasetInfo
 from ...mapper.cats import cat_to_sub_cat
 from ...mapper.xfundstruct import xfund_to_image
 from ...utils.detection_types import JsonDict, Pathlike
+from ...utils.fs import load_json
 from ...utils.settings import names
 from ..base import _BuiltInDataset
 from ..dataflow_builder import DataFlowBaseBuilder
@@ -49,19 +49,18 @@ from ..info import DatasetCategories
 from ..registry import dataset_registry
 
 
-def load_json(path_ann: Pathlike) -> JsonDict:
+def load_file(path_ann: Pathlike) -> JsonDict:
     """
     Loading json file
 
     :param path_ann: path
     :return: dict
     """
-    with open(path_ann, "r", encoding="utf-8") as file:
-        anns = json.loads(file.read())
-        path, file_name = os.path.split(path_ann)
-        base_path, _ = os.path.split(path)
-        path = os.path.join(base_path, "images")
-        anns["file_name"] = os.path.join(path, file_name[:-4] + "png")
+    anns = load_json(path_ann)
+    path, file_name = os.path.split(path_ann)
+    base_path, _ = os.path.split(path)
+    path = os.path.join(base_path, "images")
+    anns["file_name"] = os.path.join(path, file_name[:-4] + "png")
     return anns
 
 
@@ -80,6 +79,7 @@ _LICENSE = (
 
 _URL = "https://guillaumejaume.github.io/FUNSD/download/"
 _SPLITS: Mapping[str, str] = {"train": "training_data", "test": "testing_data"}
+_TYPE = names.DS.TYPE.TOK
 _LOCATION = "funsd"
 _ANNOTATION_FILES: Mapping[str, str] = {"train": "annotations", "test": "annotations"}
 
@@ -89,6 +89,15 @@ _SUB_CATEGORIES = {
     names.C.WORD: {
         names.C.SE: [names.C.O, names.C.Q, names.C.A, names.C.HEAD],
         names.NER.TAG: [names.NER.I, names.NER.O, names.NER.B],
+        names.NER.TOK: [
+            names.NER.B_A,
+            names.NER.B_H,
+            names.NER.B_Q,
+            names.NER.I_A,
+            names.NER.I_H,
+            names.NER.I_Q,
+            names.NER.O,
+        ],
     }
 }
 
@@ -103,7 +112,7 @@ class Funsd(_BuiltInDataset):
 
     @classmethod
     def _info(cls) -> DatasetInfo:
-        return DatasetInfo(name=_NAME, description=_DESCRIPTION, license=_LICENSE, url=_URL, splits=_SPLITS)
+        return DatasetInfo(name=_NAME, description=_DESCRIPTION, license=_LICENSE, url=_URL, splits=_SPLITS, type=_TYPE)
 
     def _categories(self) -> DatasetCategories:
         return DatasetCategories(init_categories=_INIT_CATEGORIES, init_sub_categories=_SUB_CATEGORIES)
@@ -143,7 +152,7 @@ class FunsdBuilder(DataFlowBaseBuilder):
 
         df = SerializerFiles.load(path_ann_files, ".json", max_datapoints)
 
-        df = MapData(df, load_json)
+        df = MapData(df, load_file)
 
         # Map
         category_names_mapping = {
@@ -152,7 +161,16 @@ class FunsdBuilder(DataFlowBaseBuilder):
             "answer": names.C.A,
             "header": names.C.HEAD,
         }
-        df = MapData(df, xfund_to_image(load_image, False, category_names_mapping))  # pylint: disable=E1120
+        ner_token_to_id_mapping = self.categories.get_sub_categories(
+            categories=names.C.WORD,
+            sub_categories={names.C.WORD: [names.NER.TOK]},
+            keys=False,
+            values_as_dict=True,
+            name_as_key=True,
+        )[names.C.WORD][names.NER.TOK]
+        df = MapData(
+            df, xfund_to_image(load_image, False, category_names_mapping, ner_token_to_id_mapping)
+        )  # pylint: disable=E1120
         if self.categories.is_cat_to_sub_cat():
             df = MapData(
                 df,
