@@ -53,7 +53,7 @@ from ..info import DatasetCategories
 from ..registry import dataset_registry
 
 if lxml_available():
-    from lxml import etree  # type: ignore
+    from lxml import etree
 
 _NAME = "pubtables1m"
 
@@ -71,6 +71,7 @@ _LICENSE = "Community Data License Agreement – Permissive, Version 1.0"
 _URL = "https://msropendata.com/datasets/505fcbe3-1383-42b1-913a-f651b8b712d3"
 
 _SPLITS: Mapping[str, str] = {"train": "train", "val": "val", "test": "test"}
+_TYPE = names.DS.TYPE.OBJ
 _LOCATION = "PubTables1M-Detection-PASCAL-VOC"
 _ANNOTATION_FILES: Mapping[str, str] = {
     "train": "train",
@@ -91,7 +92,7 @@ class Pubtables1M(_BuiltInDataset):
 
     @classmethod
     def _info(cls) -> DatasetInfo:
-        return DatasetInfo(name=_NAME, description=_DESCRIPTION, license=_LICENSE, url=_URL, splits=_SPLITS)
+        return DatasetInfo(name=_NAME, description=_DESCRIPTION, license=_LICENSE, url=_URL, splits=_SPLITS, type=_TYPE)
 
     def _categories(self) -> DatasetCategories:
         return DatasetCategories(init_categories=_INIT_CATEGORIES)
