@@ -26,6 +26,7 @@ import numpy as np
 
 from ..dataflow import DataFlow
 from ..datasets.info import DatasetCategories
+from ..mapper.cats import re_assign_cat_ids
 from ..mapper.cocostruct import image_to_coco
 from ..utils.detection_types import JsonDict
 from ..utils.file_utils import Requirement, cocotools_available, get_cocotools_requirement
@@ -126,7 +127,7 @@ class CocoMetric(MetricBase):
     def dump(
         cls, dataflow_gt: DataFlow, dataflow_predictions: DataFlow, categories: DatasetCategories
     ) -> Tuple["COCO", "COCO"]:
-        cats = [{"id": int(k), "name": v} for k, v in categories.get_categories(as_dict=True).items()]
+        cats = [{"id": int(k), "name": v} for k, v in categories.get_categories(as_dict=True, filtered=True).items()]
         imgs_gt, imgs_pr = [], []
         anns_gt, anns_pr = [], []
 
@@ -134,6 +135,9 @@ class CocoMetric(MetricBase):
 
         for dp_gt, dp_pred in zip(dataflow_gt, dataflow_predictions):
             img_gt, ann_gt = cls.mapper(dp_gt)  # type: ignore
+            dp_pred = re_assign_cat_ids(  # pylint: disable=E1120
+                categories.get_categories(as_dict=True, filtered=True, name_as_key=True)
+            )(dp_pred)
             img_pr, ann_pr = cls.mapper(dp_pred)  # type: ignore
             imgs_gt.append(img_gt)
             imgs_pr.append(img_pr)
