@@ -33,7 +33,7 @@ from ..utils.logger import logger
 from ..utils.settings import names
 from ..utils.systools import get_configs_dir_path, get_weights_dir_path
 
-__all__ = ["ModelCatalog", "ModelDownloadManager", "print_model_infos"]
+__all__ = ["ModelCatalog", "ModelDownloadManager", "print_model_infos", "ModelProfile"]
 
 
 @dataclass
@@ -260,8 +260,8 @@ class ModelCatalog:
             hf_config_file=["Base-RCNN-FPN.yaml", "CASCADE_RCNN_R_50_FPN_GN.yaml"],
             categories={"1": names.C.ROW, "2": names.C.COL},
         ),
-        "mrm8488/layoutlm-finetuned-funsd": ModelProfile(
-            name="mrm8488/layoutlm-finetuned-funsd",
+        "mrm8488/layoutlm-finetuned-funsd/pytorch_model.bin": ModelProfile(
+            name="mrm8488/layoutlm-finetuned-funsd/pytorch_model.bin",
             description="LayoutLM pre-trained on CDIP and fine tuned on funsd",
             config="mrm8488/layoutlm-finetuned-funsd/config.json",
             size=[450639205],
@@ -271,20 +271,33 @@ class ModelCatalog:
             hf_config_file=["config.json"],
             categories={
                 "1": "B-ANSWER",
-                "2": "B-HEADER",
+                "2": "B-HEAD",
                 "3": "B-QUESTION",
                 "4": "E-ANSWER",
-                "5": "E-HEADER",
+                "5": "E-HEAD",
                 "6": "E-QUESTION",
                 "7": "I-ANSWER",
-                "8": "I-HEADER",
+                "8": "I-HEAD",
                 "9": "I-QUESTION",
                 "10": "O",
                 "11": "S-ANSWER",
-                "12": "S-HEADER",
+                "12": "S-HEAD",
                 "13": "S-QUESTION",
             },
         ),
+        "microsoft/layoutlm-base-uncased/pytorch_model.bin": ModelProfile(
+            name="microsoft/layoutlm-base-uncased/pytorch_model.bin",
+            description="LayoutLM is a simple but effective pre-training method of text and layout for document image"
+            " understanding and information extraction tasks, such as form understanding and receipt"
+            " understanding. LayoutLM archived the SOTA results on multiple datasets. This model does not"
+            "contain any head and has to be fine tuned on a downstream task.",
+            size=[453093832],
+            tp_model=False,
+            config="microsoft/layoutlm-base-uncased/config.json",
+            hf_repo_id="microsoft/layoutlm-base-uncased",
+            hf_model_name="pytorch_model.bin",
+            hf_config_file=["config.json"],
+        ),
         "fasttext/lid.176.bin": ModelProfile(
             name="fasttext/lid.176.bin",
             description="Fasttext language detection model",
@@ -483,7 +496,7 @@ class ModelCatalog:
         :return: absolute weight path
         """
         profile = ModelCatalog.get_profile(name)
-        if profile.config is not None:
+        if profile.name is not None:
             return os.path.join(get_weights_dir_path(), profile.name)
         logger.info(
             "Model is not registered. Please make sure the weights are available in the weights cache " "directory"
@@ -617,6 +630,10 @@ class ModelDownloadManager:
         file_names: List[str] = []
         if ModelCatalog.is_registered(name):
             profile = ModelCatalog.get_profile(name)
+            # there is nothing to download if hf_repo_id or urls is not provided
+            if not profile.hf_repo_id and not profile.urls:
+                return absolute_path_weights
+            # determine the right model name
             if profile.tp_model:
                 file_names = get_tp_weight_names(name)
             else:
@@ -684,8 +701,13 @@ class ModelDownloadManager:
     @staticmethod
     def _load_from_hf_hub(repo_id: str, file_name: str, cache_directory: str, force_download: bool = False) -> int:
         url = hf_hub_url(repo_id=repo_id, filename=file_name)
+        use_auth_token = os.environ.get("HF_CREDENTIALS")
         f_path = cached_download(
-            url, cache_dir=cache_directory, force_filename=file_name, force_download=force_download
+            url,
+            cache_dir=cache_directory,
+            force_filename=file_name,
+            force_download=force_download,
+            use_auth_token=use_auth_token,
         )
         stat_info = os.stat(f_path)
         size = stat_info.st_size
