@@ -61,7 +61,7 @@ def decode_bbox_target(box_predictions, anchors, preproc_max_size):
     xbyb = box_pred_txty * waha + xaya
     x1y1 = xbyb - wbhb * 0.5
     x2y2 = xbyb + wbhb * 0.5  # (...)x1x2
-    out = tf.concat([x1y1, x2y2], axis=-2)  # pylint: disable =E1123
+    out = tf.concat([x1y1, x2y2], axis=-2)
     return tf.reshape(out, orig_shape)
 
 
@@ -88,7 +88,7 @@ def encode_bbox_target(boxes, anchors):
     # Note that here not all boxes are valid. Some may be zero
     txty = (xbyb - xaya) / waha
     twth = tf.math.log(wbhb / waha)  # may contain -inf for invalid boxes
-    encoded = tf.concat([txty, twth], axis=1)  # (-1x2x2)  # pylint: disable =E1123
+    encoded = tf.concat([txty, twth], axis=1)  # (-1x2x2)
     return tf.reshape(encoded, tf.shape(boxes))
 
 
@@ -111,7 +111,7 @@ def crop_and_resize(image, boxes, box_ind, crop_size, pad_border=True):
     # TF's crop_and_resize produces zeros on border
     if pad_border:
         # this can be quite slow
-        image = tf.pad(image, [[0, 0], [0, 0], [1, 1], [1, 1]], mode="SYMMETRIC")  # pylint: disable =E1123
+        image = tf.pad(image, [[0, 0], [0, 0], [1, 1], [1, 1]], mode="SYMMETRIC")
         boxes += 1
 
     @under_name_scope()
@@ -148,7 +148,7 @@ def crop_and_resize(image, boxes, box_ind, crop_size, pad_border=True):
         n_w = spacing_w * tf.cast(crop_shape[1] - 1, tf.float32) / imshape[1]
         n_h = spacing_h * tf.cast(crop_shape[0] - 1, tf.float32) / imshape[0]
 
-        return tf.concat([ny0, nx0, ny0 + n_h, nx0 + n_w], axis=1)  # pylint: disable =E1123
+        return tf.concat([ny0, nx0, ny0 + n_h, nx0 + n_w], axis=1)
 
     image_shape = tf.shape(image)[2:]
 
@@ -208,8 +208,8 @@ class RPNAnchors(namedtuple("_RPNAnchors", ["boxes", "gt_labels", "gt_boxes"])):
         Slice anchors to the spatial size of this feature map.
         """
         shape2d = tf.shape(featuremap)[2:]  # h,w
-        slice3d = tf.concat([shape2d, [-1]], axis=0)  # pylint: disable =E1123
-        slice4d = tf.concat([shape2d, [-1, -1]], axis=0)  # pylint: disable =E1123
+        slice3d = tf.concat([shape2d, [-1]], axis=0)
+        slice4d = tf.concat([shape2d, [-1, -1]], axis=0)
         boxes = tf.slice(self.boxes, [0, 0, 0, 0], slice4d)
         gt_labels = tf.slice(self.gt_labels, [0, 0, 0], slice3d)
         gt_boxes = tf.slice(self.gt_boxes, [0, 0, 0, 0], slice4d)
