@@ -21,7 +21,7 @@ Module for small mapping functions
 
 import ast
 import os
-from typing import List, Mapping, Optional, Union
+from typing import List, Mapping, Optional, Sequence, Union
 
 from ..datapoint.convert import convert_pdf_bytes_to_np_array_v2
 from ..datapoint.image import Image
@@ -31,7 +31,7 @@ from ..utils.fs import get_load_image_func, is_file_extension, load_image_from_f
 from .maputils import MappingContextManager, curry
 
 if lxml_available():
-    from lxml import etree  # type: ignore  # pylint: disable=W0611
+    from lxml import etree  # pylint: disable=W0611
 
 
 def to_image(dp: Union[str, Mapping[str, Union[str, bytes]]], dpi: Optional[int] = None) -> Optional[Image]:
@@ -103,6 +103,28 @@ def maybe_remove_image(dp: Image) -> Image:
     return dp
 
 
+@curry
+def maybe_remove_image_from_category(dp: Image, category_names: Optional[Union[str, Sequence[str]]] = None) -> Image:
+    """
+    Removes image from image annotation for some category names
+
+    :param dp: An Image
+    :param category_names: category names
+    :return: Image with image attributes from image annotations removed
+    """
+    if category_names is None:
+        category_names = []
+    elif isinstance(category_names, str):
+        category_names = [category_names]
+
+    anns = dp.get_annotation(category_names=category_names)
+
+    for ann in anns:
+        ann.image = None
+
+    return dp
+
+
 def image_ann_to_image(dp: Image, category_names: Union[str, List[str]], crop_image: bool = True) -> Image:
     """
     Adds attr: image to annotations with given category names
@@ -122,7 +144,7 @@ def image_ann_to_image(dp: Image, category_names: Union[str, List[str]], crop_im
 
 @curry
 def maybe_ann_to_sub_image(
-    dp: Image, category_names_sub_image: Union[str, List[str]], category_names: Union[str, List[str]]
+    dp: Image, category_names_sub_image: Union[str, List[str]], category_names: Union[str, List[str]], add_summary: bool
 ) -> Image:
     """
     Assigns to sub image with given category names all annotations with given category names whose bounding box lie
@@ -132,12 +154,15 @@ def maybe_ann_to_sub_image(
     :param category_names_sub_image: A single or a list of category names that will form a sub image.
     :param category_names: A single or a list of category names that will may be assigned to a sub image, conditioned
                            on the bounding box lying within the sub image.
+    :param add_summary: will add the whole summary annotation to the sub image
     :return: Image
     """
 
     anns = dp.get_annotation(category_names=category_names_sub_image)
     for ann in anns:
         dp.maybe_ann_to_sub_image(annotation_id=ann.annotation_id, category_names=category_names)
+        if add_summary and ann.image:
+            ann.image.summary = dp.summary
 
     return dp
 
