@@ -31,6 +31,7 @@ from ..datapoint.box import BoundingBox, iou
 from ..datapoint.image import Image
 from ..mapper.maputils import MappingContextManager
 from ..mapper.match import match_anns_by_intersection
+from ..utils.detection_types import JsonDict
 from ..utils.settings import names
 from .base import PipelineComponent
 from .registry import pipeline_component_registry
@@ -387,7 +388,7 @@ class TableSegmentationService(PipelineComponent):
         :param remove_iou_threshold_cols: iou threshold for removing overlapping columns
         """
         assert segment_rule in ["iou", "ioa"], "segment rule must be either iou or ioa"
-        super().__init__(None)
+
         self.segment_rule = segment_rule
         self.threshold_rows = threshold_rows
         self.threshold_cols = threshold_cols
@@ -398,6 +399,7 @@ class TableSegmentationService(PipelineComponent):
         self._cell_names = [names.C.HEAD, names.C.BODY, names.C.CELL]
         self._item_names = [names.C.ROW, names.C.COL]  # row names must be before column name
         self._sub_item_names = [names.C.RN, names.C.CN]
+        super().__init__(None)
 
     def serve(self, dp: Image) -> None:
         dp = stretch_items(
@@ -425,7 +427,7 @@ class TableSegmentationService(PipelineComponent):
                 items = dp.get_annotation(category_names=item_name, annotation_ids=item_ann_ids)
                 items.sort(
                     key=lambda x: x.bounding_box.cx  # type: ignore
-                    if item_name == names.C.COL  # pylint: disable=C0301
+                    if item_name == names.C.COL  # pylint: disable=W0640
                     else x.bounding_box.cy  # type: ignore
                 )
                 for item_number, item in enumerate(items, 1):
@@ -464,3 +466,20 @@ class TableSegmentationService(PipelineComponent):
             self.remove_iou_threshold_rows,
             self.remove_iou_threshold_cols,
         )
+
+    def get_meta_annotation(self) -> JsonDict:
+        return dict(
+            [
+                ("image_annotations", []),
+                (
+                    "sub_categories",
+                    {
+                        names.C.CELL: {names.C.RN, names.C.CN, names.C.RS, names.C.CS},
+                        names.C.ROW: {names.C.RN},
+                        names.C.COL: {names.C.CN},
+                    },
+                ),
+                ("relationships", {}),
+                ("summaries", []),
+            ]
+        )
