@@ -58,6 +58,13 @@ _N.C.HTAB = "HTML_TABLE"
 _N.C.RO = "READING_ORDER"
 _N.C.LOGO = "LOGO"
 _N.C.SIGN = "SIGNATURE"
+_N.C.CAP = "CAPTION"
+_N.C.FOOT = "FOOTNOTE"
+_N.C.FORMULA = "FORMULA"
+_N.C.PFOOT = "PAGE-FOOTER"
+_N.C.PHEAD = "PAGE-HEADER"
+_N.C.SECH = "SECTION-HEADER"
+_N.C.PAGE = "PAGE"
 
 _N.C.SEL = "SEMANTIC_ENTITY_LINK"
 _N.C.SE = "SEMANTIC_ENTITY"
@@ -65,11 +72,43 @@ _N.C.Q = "QUESTION"
 _N.C.A = "ANSWER"
 _N.C.O = "OTHER"
 
+_N.C.DOC = "DOC_CLASS"
+
+_N.C.LET = "LETTER"
+_N.C.FORM = "FORM"
+_N.C.EM = "EMAIL"
+_N.C.HW = "HANDWRITTEN"
+_N.C.AD = "ADVERTISMENT"
+_N.C.SR = "SCIENTIFIC REPORT"
+_N.C.SP = "SCIENTIFIC PUBLICATION"
+_N.C.SPEC = "SPECIFICATION"
+_N.C.FF = "FILE FOLDER"
+_N.C.NA = "NEWS ARTICLE"
+_N.C.BU = "BUDGET"
+_N.C.INV = "INVOICE"
+_N.C.PRES = "PRESENTATION"
+_N.C.QUEST = "QUESTIONNAIRE"
+_N.C.RES = "RESUME"
+_N.C.MEM = "MEMO"
+_N.C.FR = "FINANCIAL_REPORTS"
+_N.C.LR = "LAWS_AND_REGULATIONS"
+_N.C.GT = "GOVERNMENT_TENDERS"
+_N.C.MAN = "MANUALS"
+_N.C.PAT = "PATENTS"
+
 _N.NER.TAG = "NER_TAG"
 _N.NER.O = "O"
 _N.NER.B = "B"
 _N.NER.I = "I"
 
+_N.NER.TOK = "NER_TOKEN"
+_N.NER.B_A = "B-ANSWER"
+_N.NER.B_H = "B-HEAD"
+_N.NER.B_Q = "B-QUESTION"
+_N.NER.I_A = "I-ANSWER"
+_N.NER.I_H = "I-HEAD"
+_N.NER.I_Q = "I-QUESTION"
+
 _N.NLP.LANG.LANG = "LANGUAGE"
 _N.NLP.LANG.ENG = "eng"
 _N.NLP.LANG.RUS = "rus"
@@ -130,6 +169,9 @@ _N.NLP.LANG.BOS = "bos"
 _N.NLP.LANG.NNO = "nno"
 _N.NLP.LANG.URD = "urd"
 
+_N.DS.TYPE.OBJ = "OBJECT_DETECTION"
+_N.DS.TYPE.SEQ = "SEQUENCE_CLASSIFICATION"
+_N.DS.TYPE.TOK = "TOKEN_CLASSIFICATION"
 
 _N.freeze()
 
