@@ -222,7 +222,7 @@ def draw_text(
 def draw_boxes(
     np_image: ImageType,
     boxes: npt.NDArray[float32],
-    category_names_list: Optional[List[str]] = None,
+    category_names_list: Optional[List[Optional[str]]] = None,
     color: Optional[Tuple[int, int, int]] = None,
 ) -> ImageType:
     """
@@ -257,7 +257,10 @@ def draw_boxes(
         box = boxes[i, :]
         if category_names_list is not None:
             choose_color = random_color() if color is None else color
-            np_image = draw_text(np_image, (box[0], box[1]), category_names_list[i], color=choose_color, font_scale=1.0)
+            if category_names_list[i] is not None:
+                np_image = draw_text(
+                    np_image, (box[0], box[1]), category_names_list[i], color=choose_color, font_scale=1.0
+                )
             cv2.rectangle(np_image, (box[0], box[1]), (box[2], box[3]), color=choose_color, thickness=4)
     return np_image
 
