@@ -26,7 +26,7 @@ from numpy.testing import assert_array_almost_equal, assert_array_equal
 from deepdoctection.dataflow import CustomDataFromList, MeanFromDataFlow, StdFromDataFlow
 
 
-class TestMeanFromDataFlow:  # pylint: disable=too-few-public-methods
+class TestMeanFromDataFlow:
     """
     Testing MeanFromDataFlow along various dimensions
     """
@@ -62,7 +62,7 @@ class TestMeanFromDataFlow:  # pylint: disable=too-few-public-methods
         assert_array_equal(mean, np.array(mean_all_axes))
 
 
-class TestStdFromDataFlow:  # pylint: disable=too-few-public-methods
+class TestStdFromDataFlow:
     """
     Testing StdFromDataFlow along various dimensions
     """
