@@ -21,6 +21,8 @@ Testing module extern.texocr
 
 from unittest.mock import MagicMock, patch
 
+from pytest import mark
+
 from deepdoctection.extern.texocr import TextractOcrDetector
 from deepdoctection.utils.detection_types import ImageType, JsonDict
 
@@ -31,6 +33,7 @@ class TestTextractOcrDetector:  # pylint: disable=R0903
     """
 
     @staticmethod
+    @mark.all
     @patch("deepdoctection.extern.texocr.get_aws_requirement", MagicMock(return_value=("boto3", True, "")))
     @patch("deepdoctection.extern.texocr.get_boto3_requirement", MagicMock(return_value=("aws", True, "")))
     @patch("deepdoctection.extern.texocr.boto3", MagicMock())
