@@ -35,16 +35,16 @@ def test_to_page(dp_image_with_layout_and_word_annotations: Image) -> None:
     # Arrange
     dp_image = dp_image_with_layout_and_word_annotations
     title_ann = dp_image.get_annotation(category_names=[names.C.TITLE])[0]
-    title_ann.dump_sub_category(names.C.RO, CategoryAnnotation(category_name=names.C.RO, category_id=1))
+    title_ann.dump_sub_category(names.C.RO, CategoryAnnotation(category_name=names.C.RO, category_id="1"))
     text_ann = dp_image.get_annotation(category_names=[names.C.TEXT])[0]
-    text_ann.dump_sub_category(names.C.RO, CategoryAnnotation(category_name=names.C.RO, category_id=2))
+    text_ann.dump_sub_category(names.C.RO, CategoryAnnotation(category_name=names.C.RO, category_id="2"))
 
     word_anns = dp_image.get_annotation(category_names=names.C.WORD)
 
-    word_anns[0].dump_sub_category(names.C.RO, CategoryAnnotation(category_name=names.C.RO, category_id=1))
-    word_anns[1].dump_sub_category(names.C.RO, CategoryAnnotation(category_name=names.C.RO, category_id=2))
-    word_anns[2].dump_sub_category(names.C.RO, CategoryAnnotation(category_name=names.C.RO, category_id=1))
-    word_anns[3].dump_sub_category(names.C.RO, CategoryAnnotation(category_name=names.C.RO, category_id=2))
+    word_anns[0].dump_sub_category(names.C.RO, CategoryAnnotation(category_name=names.C.RO, category_id="1"))
+    word_anns[1].dump_sub_category(names.C.RO, CategoryAnnotation(category_name=names.C.RO, category_id="2"))
+    word_anns[2].dump_sub_category(names.C.RO, CategoryAnnotation(category_name=names.C.RO, category_id="1"))
+    word_anns[3].dump_sub_category(names.C.RO, CategoryAnnotation(category_name=names.C.RO, category_id="2"))
 
     # Act
     page = to_page(
