@@ -55,7 +55,7 @@ def collect_datapoint_from_dataflow(
 
     output: List[Any] = []
     if hasattr(df, "reset_state"):
-        df.reset_state()
+        df.reset_state()  # type: ignore
 
     for idx, dp in enumerate(df):
         if max_datapoints is not None:
@@ -75,3 +75,10 @@ def anns_to_ids(annotations: Union[Iterable[Annotation], List[Annotation]]) -> L
     """
 
     return [ann.annotation_id for ann in annotations]
+
+
+def set_num_gpu_to_one() -> int:
+    """
+    set gpu number to one
+    """
+    return 1
